@@ -1,6 +1,6 @@
 package List::Objects::WithUtils::Role::Array;
 {
-  $List::Objects::WithUtils::Role::Array::VERSION = '1.009004';
+  $List::Objects::WithUtils::Role::Array::VERSION = '1.009005';
 }
 use strictures 1;
 
@@ -145,6 +145,14 @@ sub map {
   )
 }
 
+sub mapval {
+  my ($self, $sub) = @_;
+  my @copy = @$self;
+  blessed_or_pkg($_[0])->new(
+    CORE::map {; $sub->($_); $_ } @copy
+  )
+}
+
 sub grep {
   blessed_or_pkg($_[0])->new(
     CORE::grep {; $_[1]->($_) } @{ $_[0] }
@@ -654,6 +662,22 @@ Evaluates a given subroutine for each element of the array, and returns a new
 array object. C<$_[0]> is the element being operated on; you can also use
 the topicalizer C<$_>.
 
+Also see L</mapval>.
+
+=head3 mapval
+
+  my $orig = array(1, 2, 3);
+  my $incr = $orig->mapval(sub { ++$_ });
+
+  $incr->all;  # (2, 3, 4)
+  $orig->all;  # Still untouched
+
+An alternative to L</map>. C<$_> is a copy, rather than an alias to the
+current element, and the result is retrieved from the altered C<$_> rather
+than the return value of the block.
+
+This feature is borrowed from L<Data::Munge> by Lukas Mai (CPAN: MAUKE).
+
 =head3 natatime
 
   my $iter = array( 1 .. 7 )->natatime(3);
